@@ -17,7 +17,7 @@ import gen3git
 from gen3utils.manifest.manifest_validator import version_is_branch
 from gen3utils.utils import submit_comment, version_is_monthly_release
 
-logger = get_logger("comment-deployment-changes", log_level="info")
+logger = get_logger("comment-deployment-changes", log_level="debug")
 
 
 # whitelist of services to ignore when checking tags and services on branch
@@ -33,6 +33,7 @@ IGNORED_SERVICES = [
     "acronymbot",
     "cedar-wrapper",
     "kayako-wrapper",
+    "frontend-framework",
 ]
 
 # update this config if the service name in the manifest "versions"
@@ -53,6 +54,12 @@ SERVICE_TO_REPO = {
     "cedar-wrapper": "cedar-wrapper-service",
     "kayako-wrapper": "kayako-wrapper-service",
     "frontend-framework": "gen3-frontend-framework",
+    "metadata-delete-expired-objects": "sower-jobs",
+    "ssjdispatcher.job_images.indexing": "indexs3client",
+    "_regex": {
+        r"^sower\..*\.pelican-.*$": "pelican",
+        r"^sower\..*\.(?:manifest-indexing|download-indexd-manifest|manifest-merging|metadata-manifest-ingestion|get-dbgap-metadata|batch-export|metadata-delete-expired-objects)$": "sower-jobs",
+    },
 }
 
 
@@ -99,7 +106,7 @@ def comment_deployment_changes_on_pr(repository, pull_request_number):
         logger.info("- {}".format(file_info["filename"]))
         url = file_info["raw_url"]
         old_file, new_file = get_files(get_master_url(url), url, headers)
-        new_versions_block = new_file.get("versions", {})
+        new_versions_block = get_versions_dict(new_file)
         new_is_nde_portal = "data-ecosystem-portal" in new_versions_block.get(
             "portal", ""
         )
@@ -108,7 +115,7 @@ def comment_deployment_changes_on_pr(repository, pull_request_number):
             new_versions_block.pop(service_name, None)
 
         if old_file:
-            old_versions_block = old_file.get("versions", {})
+            old_versions_block = get_versions_dict(old_file)
             for service_name in IGNORED_SERVICES:
                 old_versions_block.pop(service_name, None)
 
@@ -182,6 +189,36 @@ def get_files(master_url, pr_url, headers):
     return old_file, new_file
 
 
+def get_versions_dict(manifest):
+    """
+    Returns:
+    dict { <image name>: <image url> }
+
+    Example:
+    { "fence": "quay.io/cdis/fence:1.0.0",  "ssjdispatcher.job_images.indexing": "quay.io/cdis/ssjdispatcher:2.0.0" }
+
+    TODO: check the `manifests/hatchery/hatchery.json` file or `manifest.json->hatchery` section
+    """
+    versions = manifest.get("versions", {})
+    for ssj_name, ssj_image in (
+        manifest.get("ssjdispatcher", {}).get("job_images", {}).items()
+    ):
+        versions[f"ssjdispatcher.job_images.{ssj_name}"] = ssj_image
+    for sower_job in manifest.get("sower", []):
+        container = sower_job.get("container", {})
+        image = container.get("image")
+        if image:
+            name = image.split("/")[-1].split(":")[0]
+            versions[f"sower.container.image.{name}"] = image
+    for jupyter_container in manifest.get("jupyterhub", {}).get("containers", []):
+        image = jupyter_container.get("image")
+        if image:
+            versions[
+                f"jupyterhub.containers.image.{jupyter_container.get('name')}"
+            ] = image
+    return versions
+
+
 def compare_versions_blocks(old_versions_block, new_versions_block, check_portal):
     """
     Returns a dict:
@@ -266,14 +303,8 @@ def get_important_changes(versions_dict, token, is_nde_portal):
         if not version_is_branch(
             versions["old"], release_tag_are_branches=False
         ) and not version_is_branch(versions["new"], release_tag_are_branches=False):
-            # by default, assume the code lives in repo uc-cdis/<service name>
-            repo_name = SERVICE_TO_REPO.get(service, service)
-
-            # repo names special cases
-            if service == "portal" and is_nde_portal:
-                repo_name = "data-ecosystem-portal"
-
-            repo_name = "uc-cdis/" + repo_name
+            repo_name = get_repo_name(service, is_nde_portal)
+            logger.debug(f"Mapped service/image name '{service}' to repo '{repo_name}'")
             args = Gen3GitArgs(repo_name, versions["old"], versions["new"])
             try:
                 release_notes = gen3git.main(args)
@@ -295,6 +326,24 @@ def get_important_changes(versions_dict, token, is_nde_portal):
     return deployment_changes, breaking_changes
 
 
+def get_repo_name(service, is_nde_portal=False):
+    # by default, assume the code lives in repo uc-cdis/<service name>
+    repo_name = SERVICE_TO_REPO.get(service, service)
+
+    # try to match the service name to one of the configured regex
+    if service not in SERVICE_TO_REPO:
+        for reg, matched_repo in SERVICE_TO_REPO["_regex"].items():
+            if re.match(reg, service):
+                repo_name = matched_repo
+                break
+
+    # repo names special cases
+    if service == "portal" and is_nde_portal:
+        repo_name = "data-ecosystem-portal"
+
+    return "uc-cdis/" + repo_name
+
+
 def get_downgraded_services(compared_versions):
     """
     Return: list of downgraded services names
@@ -334,7 +383,7 @@ def update_pr_links(repo_name, notes_list):
     in each release note.
     """
     result = []
-    matcher = re.compile(".*\(#(?P<pr_number>[0-9]+)\)$")
+    matcher = re.compile(r".*\(#(?P<pr_number>[0-9]+)\)$")
     # e.g. gets the PR number ("12") from "some description (#12)"
     for note in notes_list:
         match = matcher.match(note)
